nengo\_spa\.exceptions
======================

.. automodule:: nengo_spa.exceptions
   :show-inheritance:

   .. rubric:: Exceptions

   .. autosummary::

      SpaActionSelectionError
      SpaException
      SpaParseError
      SpaTypeError
